def validate_webapp_data(webapp_data: dict[str, str], secret_key: bytes) -> bool:
    """
    Check if the bot is authorized to send messages to the user

    :param bot_token: Telegram bot token
    :param webapp_data: Webapp data

    :return: True if the bot is authorized to send messages to the user, False otherwise
    """


def get_secret_key(bot_token: str) -> bytes:
    """
    Get the secret key
    
    :param bot_token: Telegram bot token

    :return: The secret key
    """
    
def parse_webapp_data(webapp_data: str) -> dict[str, str]:
    """
    Parse the webapp data
    
    :param webapp_data: Webapp data

    :return: The parsed webapp data
    """


from fastapi import Request, FastAPI
from teleapp_auth import get_secret_key, parse_webapp_data, validate_webapp_data


app = FastAPI()
secret_key = get_secret_key("BOT_TOKEN")


@app.post("/check_data")
async def check_data(request: Request) -> bool:
    request_json = await request.json()
    auth_data = request_json.get("auth_data")
    webapp_data = parse_webapp_data(auth_data)

    return validate_webapp_data(webapp_data, secret_key)
